//////////////////////////////////////////////////////////////////////////////
//
//  Xilinx, Inc. 2006                 www.xilinx.com
//
//////////////////////////////////////////////////////////////////////////////
//
//  File name :       top_ddr3.v
//
//  Description :     Generic top level file to show LVDS pin inversion for 
//			DDR registered inputs (Spartan 3E using IDDR2)
//
//  Date - revision : April 4th 2006 - v 1.0
//
//  Disclaimer: LIMITED WARRANTY AND DISCLAMER. These designs are
//              provided to you "as is". Xilinx and its licensors make and you
//              receive no warranties or conditions, express, implied,
//              statutory or otherwise, and Xilinx specifically disclaims any
//              implied warranties of merchantability, non-infringement,or
//              fitness for a particular purpose. Xilinx does not warrant that
//              the functions contained in these designs will meet your
//              requirements, or that the operation of these designs will be
//              uninterrupted or error free, or that defects in the Designs
//              will be corrected. Furthermore, Xilinx does not warrantor
//              make any representations regarding use or the results of the
//              use of the designs in terms of correctness, accuracy,
//              reliability, or otherwise.
//
//              LIMITATION OF LIABILITY. In no event will Xilinx or its
//              licensors be liable for any loss of data, lost profits,cost
//              or procurement of substitute goods or services, or for any
//              special, incidental, consequential, or indirect damages
//              arising from the use or operation of the designs or
//              accompanying documentation, however caused and on any theory
//              of liability. This limitation will apply even if Xilinx
//              has been advised of the possibility of such damage. This
//              limitation shall apply not-withstanding the failure of the
//              essential purpose of any limited remedies herein.
//
//  Copyright  2006 Xilinx, Inc.
//  All rights reserved
//
//////////////////////////////////////////////////////////////////////////////	
`timescale 1 ps / 1ps

module top_ddr3(
input		clkin,				// clock input
input	[2:0]	datain_p, datain_n, 		// data inputs
output		tp) ;				// tp

wire 	[2:0]	rx_input ;			//
wire 	[5:0]	rx_input_reg ;			//
wire 	[5:0]	rx_input_fix ;			//
wire 		notclk ;

parameter [2:0] SWAP_MASK = 3'b101 ;

assign notclk = ~clkin ;

genvar i ;
generate
for (i = 0 ; i <= 2 ; i = i + 1)
begin : loop0
IBUFDS	#(.IOSTANDARD("LVDS_25"), .IFD_DELAY_VALUE("0"), .DIFF_TERM("FALSE")) 	
ibuf_d   (.I(datain_p[i]), .IB(datain_n[i]), .O(rx_input[i]));
IDDR2 	#(.DDR_ALIGNMENT("C0")) fd_ioc	(.C0(clkin), .C1(notclk), .D(rx_input[i]), .CE(1'b1), .R(1'b0), .S(1'b0), .Q0(rx_input_reg[i+3]), .Q1(rx_input_reg[i])) ;
assign rx_input_fix[i] = rx_input_reg[i] ^ SWAP_MASK[i] ;
assign rx_input_fix[i+3] = rx_input_reg[i+3] ^ SWAP_MASK[i] ;
end
endgenerate

assign tp = rx_input_fix[5] & rx_input_fix[4] & rx_input_fix[3] & rx_input_fix[2] & rx_input_fix[1] & rx_input_fix[0] ;

endmodule
